==> JobOffers-0.2.0-py2.py3-none-any.whl: job_offers/helpers.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Fieldset, Submit, Row, Column, Field


class ApplicationFormHelper(FormHelper):
    form_action = ''
    layout = Layout(
        Row(
            Column(
                Field('first_name', placeholder=ugettext_lazy('first name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('last_name', placeholder=ugettext_lazy('last name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('email', placeholder=ugettext_lazy('email')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('phone', placeholder=ugettext_lazy('phone')),
                css_class='large-6 medium-6 small-12'),
            Column(
                Field('message', placeholder=ugettext_lazy('message')),
                css_class='large-12 medium-12 small-12',
            ),
            Fieldset(
                ugettext_lazy('Applications'),
                Column(
                    Field('cv', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('cover_letter', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('other_document', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
            ),
        ),
        Row(
            Column(
                Submit('submit', ugettext_lazy('OK')),
                css_class='large-12 medium-12 small-12 text-center'),
        ),
    )


class SearchFormHelper(FormHelper):
    FormHelper()
    form_action = '.'
    form_method = 'get'

    layout = Layout(
        Column(
            Field('keywords', placeholder=ugettext_lazy('keywords')),
            css_class='large-3 medium-4 small-12',
        ),
        Column(
            Field('contract_type', placeholder=ugettext_lazy('contract_type')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Field('location', placeholder=ugettext_lazy('location')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Submit('search', ugettext_lazy('Find')),
            css_class='large-1 medium-2 small-12',
        ),
    )

==> JobOffers-0.3.0-py2.py3-none-any.whl: job_offers/helpers.py <==
# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy

from crispy_forms.helper import FormHelper
from crispy_forms_foundation.layout import Layout, Fieldset, Submit, Row, Column, Field


class ApplicationFormHelper(FormHelper):
    form_action = ''
    layout = Layout(
        Row(
            Column(
                Field('first_name', placeholder=ugettext_lazy('first name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('last_name', placeholder=ugettext_lazy('last name')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('email', placeholder=ugettext_lazy('email')),
                css_class='large-6 medium-6 small-12',
            ),
            Column(
                Field('phone', placeholder=ugettext_lazy('phone')),
                css_class='large-6 medium-6 small-12'),
            Column(
                Field('message', placeholder=ugettext_lazy('message')),
                css_class='large-12 medium-12 small-12',
            ),
            Fieldset(
                ugettext_lazy('Applications'),
                Column(
                    Field('cv', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('cover_letter', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
                Column(
                    Field('other_document', placeholder=ugettext_lazy('cv')),
                    css_class='large-4 medium-12 small-12 '),
            ),
        ),
        Row(
            Column(
                Submit('submit', ugettext_lazy('OK')),
                css_class='large-12 medium-12 small-12 text-center'),
        ),
    )


class SearchFormHelper(FormHelper):
    form_action = '.'
    form_method = 'get'

    layout = Layout(
        Column(
            Field('keywords', placeholder=ugettext_lazy('keywords')),
            css_class='large-3 medium-4 small-12',
        ),
        Column(
            Field('contract_type', placeholder=ugettext_lazy('Contract Type')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Field('location', placeholder=ugettext_lazy('location')),
            css_class='large-4 medium-3 small-12',
        ),
        Column(
            Submit('search', ugettext_lazy('Find')),
            css_class='large-1 medium-2 small-12',
        ),
    )
